@@ -1,26 +1,35 @@
+use 5.006;    # our
 use strict;
 use warnings;
 
 package App::DH;
-BEGIN {
-  $App::DH::AUTHORITY = 'cpan:MSTROUT';
-}
-{
-  $App::DH::VERSION = '0.001002';
-}
+
+our $VERSION = '0.002000';
 
 # ABSTRACT: Deploy your DBIx::Class Schema to DDL/Database via DBIx::Class::DeploymentHandler
 
+our $AUTHORITY = 'cpan:MSTROUT'; # AUTHORITY
+
+use Carp qw( croak );
 use DBIx::Class::DeploymentHandler;
-use Moose;
+use Moose qw( with has around );
 use MooseX::Getopt 0.48 ();
-use MooseX::AttributeShortcuts;
-
-
 
 with 'MooseX::Getopt';
 
 
+
+
+
+
+
+
+
+
+
+
+
+
 has connection_name => (
   traits        => ['Getopt'],
   is            => ro =>,
@@ -32,6 +41,13 @@ has connection_name => (
 );
 
 
+
+
+
+
+
+
+
 has force => (
   traits        => ['Getopt'],
   is            => ro =>,
@@ -42,6 +58,16 @@ has force => (
 );
 
 
+
+
+
+
+
+
+
+
+
+
 has schema => (
   traits        => ['Getopt'],
   is            => ro =>,
@@ -52,6 +78,18 @@ has schema => (
 );
 
 
+
+
+
+
+
+
+
+
+
+
+
+
 has include => (
   traits        => ['Getopt'],
   is            => ro =>,
@@ -62,6 +100,18 @@ has include => (
 );
 
 
+
+
+
+
+
+
+
+
+
+
+
+
 has script_dir => (
   traits        => ['Getopt'],
   is            => ro =>,
@@ -72,16 +122,32 @@ has script_dir => (
 );
 
 
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 has database => (
   traits        => ['Getopt'],
-  is            => lazy =>,
+  is            => 'ro',
+  lazy          => 1,
+  builder       => '_build_database',
   isa           => ArrayRef =>,
   cmd_aliases   => d =>,
-  documentation => 'database backends to generate DDLs for. See SQL::Translator::Producer:: for valid values',
+  documentation => 'SQL::Translator::Producer::* database backends to generate DDLs for',
 );
 
-has _dh     => ( is => 'lazy' );
-has _schema => ( is => 'lazy' );
+has _dh     => ( is => 'ro', lazy => 1, builder => '_build__dh' );
+has _schema => ( is => 'ro', lazy => 1, builder => '_build__schema' );
 
 sub _build__schema {
   my ($self) = @_;
@@ -100,7 +166,7 @@ sub _build__dh {
       force_overwrite  => $self->force,
       script_directory => $self->script_dir,
       databases        => $self->database,
-    }
+    },
   );
 }
 
@@ -124,6 +190,13 @@ sub _build_database {
 }
 
 
+
+
+
+
+
+
+
 sub cmd_write_ddl {
   my ($self) = @_;
   $self->_dh->prepare_install;
@@ -132,14 +205,21 @@ sub cmd_write_ddl {
     $self->_dh->prepare_upgrade(
       {
         from_version => $v - 1,
-        to_version   => $v
-      }
+        to_version   => $v,
+      },
     );
   }
   return;
 }
 
 
+
+
+
+
+
+
+
 sub cmd_install {
   my $self = shift;
   $self->_dh->install;
@@ -147,6 +227,13 @@ sub cmd_install {
 }
 
 
+
+
+
+
+
+
+
 sub cmd_upgrade { shift->_dh->upgrade; return }
 
 my (%cmds) = (
@@ -165,8 +252,18 @@ my $list_cmds_usage =
   ( join qq{\n}, q{}, qq{\tcommands:}, q{}, ( map { ( sprintf qq{\t%-30s%s}, $_, $cmd_desc{$_} ) } sort keys %cmds ), q{} );
 
 
+
+
+
+
+
+
+
+
+
+
 around print_usage_text => sub {
-  my ( $orig, $self, $usage ) = @_;
+  my ( undef, undef, $usage ) = @_;
   my ($text) = $usage->text();
   $text =~ s{
         ( long\s+options[.]+[]] )
@@ -174,16 +271,16 @@ around print_usage_text => sub {
         $1 . ' ' . $list_cmds_opt
     }msex;
   $text .= qq{\n} . $text . $list_cmds_usage . qq{\n};
-  print $text or die q[Cannot write to STDOUT];
+  print $text or croak q[Cannot write to STDOUT];
   exit 0;
 };
 
 sub run {
   my ($self) = @_;
   my ( $cmd, @what ) = @{ $self->extra_argv };
-  die "Must supply a command\nCommands: $list_cmds\n" unless $cmd;
-  die "Extra argv detected - command only please\n" if @what;
-  die "No such command ${cmd}\nCommands: $list_cmds\n"
+  croak "Must supply a command\nCommands: $list_cmds\nFailed" unless $cmd;
+  croak "Extra argv detected - command only please\nFailed" if @what;
+  croak "No such command ${cmd}\nCommands: $list_cmds\nFailed"
     unless exists $cmds{$cmd};
   my $code = $cmds{$cmd};
   return $self->$code();
@@ -198,7 +295,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -206,7 +303,7 @@ App::DH - Deploy your DBIx::Class Schema to DDL/Database via DBIx::Class::Deploy
 
 =head1 VERSION
 
-version 0.001002
+version 0.002000
 
 =head1 SYNOPSIS
 
@@ -253,6 +350,11 @@ If you don't like any of the defaults, you can subclass to override
     }
     MyApp->new_with_options->run;
 
+=head1 DESCRIPTION
+
+App::DH is a basic skeleton of a command line interface for the excellent
+L<< C<DBIx::Class::DeploymentHandler>|DBIx::Class::DeploymentHandler >>, to make executing database deployment stages easier.
+
 =head1 COMMANDS
 
 =head2 write_ddl
@@ -261,7 +363,7 @@ Only generate ddls for deploy/upgrade
 
     dh.pl [...params] write_ddl
 
-=head2 write_ddl
+=head2 install
 
 Install to connection L</--connection_name>
 
@@ -336,26 +438,27 @@ Can be specified multiple times.
 
 Default is introspected from looking at whatever L</--connection_name> connects to.
 
-=head1 CREDITS
-
-This module is mostly code by mst, sponsored by L<nordaaker.com|http://nordaaker.com>, and I've only tidied it up and made it more CPAN Friendly.
-
-=head1 SPONSORS
-
-The authoring of the initial incarnation of this code is kindly sponsored by L<nordaaker.com|http://nordaaker.com>.
-
 =for Pod::Coverage     cmd_write_ddl
     cmd_install
     cmd_upgrade
     run
 
+=head1 CREDITS
+
+This module is mostly code by mst, sponsored by L<nordaaker.com|http://nordaaker.com>, and I've only tidied it up and made it
+more CPAN Friendly.
+
+=head1 SPONSORS
+
+The authoring of the initial incarnation of this code is kindly sponsored by L<nordaaker.com|http://nordaaker.com>.
+
 =head1 AUTHORS
 
 =over 4
 
 =item *
 
-kentnl - Kent Fredric (cpan:KENTNL) <kentfredric@gmail.com>
+kentnl - Kent Fredric (cpan:KENTNL) <kentnl@cpan.org>
 
 =item *
 
@@ -365,7 +468,7 @@ mst - Matt S. Trout (cpan:MSTROUT) <mst@shadowcat.co.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by The App::DH Authors, Contributors, and Sponsors.
+This software is copyright (c) 2015 by The App::DH Authors, Contributors, and Sponsors.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
